from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('attributes', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attributeschema',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='attributeset',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]
